Skip to contents

Plot the input variables. Regarding imprecise probability distribution, it plots the p-box of the imprecise probability distribution itself as well as its parameters. Note that plotting the imprecise probability distribution requires solving an optimisation problem using the "L-BFGS-B" algorithm by assuming independdance of dependence among the alpha-cuts of imprecise parameters.

Usage

plot_input(input, N = 1000, mode = "IND")

Arguments

input

List of inputs with arguments as specified in create_input().

N

Integer corresponding to the number of random samples (to be used for plotting imprecise probability distributions only). By default N = 1000.

mode

String to specify the dependence or the independence among the imprecise parameters (to be used for plotting imprecise probability distributions only): "IND" (independence) or "DEP" (dependence), see PROPAG.

Value

It provides a plot of the input variables.

See also