Depict the lower and upper CDFs
plot_cdf.RdCreate a plot summarizing the uncertainty propagation in the form of a pair of lower and upper Cumulative Distribution Function CDFs.
Arguments
- Z0
Output of the uncertainty propagation function PROPAG().
- new
Logical (by default TRUE) to create a new plot or to add CDFs to an existing plot. By default new=TRUE.
- color1
Color of the upper CDF. By default color1=1.
- color2
Color of the lower CDF. By default color2=2.
- ...
Further arguments usually passed to the plot function (e.g. xlab, ylab, main, etc.)