Interval of probability of exceedance.
proba_interval.RdFunction for summarizing the uncertainty propagation's results in the form of an interval of probability of exceedance for a given threshold.
Arguments
- Z0
Output of the uncertainty propagation function propag().
- threshold
Scalar value specifying the threshold for which the probability of exceedance should be calculated.
Details
Details of the theory and the example in Dubois & Guyonnet (2011) Available at: https://hal-brgm.archives-ouvertes.fr/file/index/docid/578821/filename/Uncertainties_RA_09_l_dg.pdf