Interval of quantiles at a given level.
quan_interval.Rdfunction for summarizing the uncertainty propagation's results in the form of an interval of quantiles at a given level. By default, the median value is provided (level = 0.5).
Arguments
- Z0
Output of the uncertainty propagation function propag()
- level
Value of the quantile level (e.g. 0.80 corresponds to the 80% quantile).
Details
Details of the theory and the example in Dubois & Guyonnet (2011) Available at: https://hal-brgm.archives-ouvertes.fr/file/index/docid/578821/filename/Uncertainties_RA_09_l_dg.pdf